You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by am...@apache.org on 2023/01/26 14:46:27 UTC

[ignite-3] branch ignite-18625 created (now 2473d18efc)

This is an automated email from the ASF dual-hosted git repository.

amashenkov pushed a change to branch ignite-18625
in repository https://gitbox.apache.org/repos/asf/ignite-3.git


      at 2473d18efc Unmute tests. ignite-17304

This branch includes the following new commits:

     new 4a30d1e670 Unmute tests. ignite-16952
     new c10aa26423 Unmute tests. ignite-16905
     new 2473d18efc Unmute tests. ignite-17304

The 3 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.



[ignite-3] 01/03: Unmute tests. ignite-16952

Posted by am...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

amashenkov pushed a commit to branch ignite-18625
in repository https://gitbox.apache.org/repos/asf/ignite-3.git

commit 4a30d1e670023420a7c2d953711145f4b85be56f
Author: amashenkov <an...@gmail.com>
AuthorDate: Thu Jan 26 16:50:57 2023 +0300

    Unmute tests. ignite-16952
---
 .../apache/ignite/internal/runner/app/client/ItThinClientSqlTest.java    | 1 -
 1 file changed, 1 deletion(-)

diff --git a/modules/runner/src/integrationTest/java/org/apache/ignite/internal/runner/app/client/ItThinClientSqlTest.java b/modules/runner/src/integrationTest/java/org/apache/ignite/internal/runner/app/client/ItThinClientSqlTest.java
index 4ca74083e8..1a9da89ce7 100644
--- a/modules/runner/src/integrationTest/java/org/apache/ignite/internal/runner/app/client/ItThinClientSqlTest.java
+++ b/modules/runner/src/integrationTest/java/org/apache/ignite/internal/runner/app/client/ItThinClientSqlTest.java
@@ -352,7 +352,6 @@ public class ItThinClientSqlTest extends ItAbstractThinClientTest {
     }
 
     @Test
-    @Disabled("IGNITE-16952")
     void testTransactionRollbackRevertsSqlUpdate() {
         Session session = client().sql().createSession();
 


[ignite-3] 03/03: Unmute tests. ignite-17304

Posted by am...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

amashenkov pushed a commit to branch ignite-18625
in repository https://gitbox.apache.org/repos/asf/ignite-3.git

commit 2473d18efc7983e078d06cc3adf8d9a63e785fb4
Author: amashenkov <an...@gmail.com>
AuthorDate: Thu Jan 26 17:34:16 2023 +0300

    Unmute tests. ignite-17304
---
 .../org/apache/ignite/internal/sql/engine/ItJoinTest.java  |  5 ++---
 .../ignite/internal/sql/engine/ItOrToUnionRuleTest.java    | 14 +++++++-------
 .../ignite/internal/sql/engine/ItSortAggregateTest.java    |  5 ++---
 3 files changed, 11 insertions(+), 13 deletions(-)

diff --git a/modules/runner/src/integrationTest/java/org/apache/ignite/internal/sql/engine/ItJoinTest.java b/modules/runner/src/integrationTest/java/org/apache/ignite/internal/sql/engine/ItJoinTest.java
index 369c46b09c..c6dea517fd 100644
--- a/modules/runner/src/integrationTest/java/org/apache/ignite/internal/sql/engine/ItJoinTest.java
+++ b/modules/runner/src/integrationTest/java/org/apache/ignite/internal/sql/engine/ItJoinTest.java
@@ -40,9 +40,8 @@ public class ItJoinTest extends AbstractBasicIntegrationTest {
         sql("CREATE TABLE t1 (id INT PRIMARY KEY, c1 INT NOT NULL, c2 INT, c3 INT)");
         sql("CREATE TABLE t2 (id INT PRIMARY KEY, c1 INT NOT NULL, c2 INT, c3 INT)");
 
-        // TODO: support indexes. https://issues.apache.org/jira/browse/IGNITE-17304
-        // sql("create index t1_idx on t1 (c3, c2, c1)");
-        // sql("create index t2_idx on t2 (c3, c2, c1)");
+         sql("create index t1_idx on t1 (c3, c2, c1)");
+         sql("create index t2_idx on t2 (c3, c2, c1)");
 
         insertData("t1", List.of("ID", "C1", "C2", "C3"),
                 new Object[] {0, 1, 1, 1},
diff --git a/modules/runner/src/integrationTest/java/org/apache/ignite/internal/sql/engine/ItSortAggregateTest.java b/modules/runner/src/integrationTest/java/org/apache/ignite/internal/sql/engine/ItSortAggregateTest.java
index ad33d71831..1c5a58e67a 100644
--- a/modules/runner/src/integrationTest/java/org/apache/ignite/internal/sql/engine/ItSortAggregateTest.java
+++ b/modules/runner/src/integrationTest/java/org/apache/ignite/internal/sql/engine/ItSortAggregateTest.java
@@ -39,9 +39,8 @@ public class ItSortAggregateTest extends AbstractBasicIntegrationTest {
         sql("CREATE TABLE test (id INT PRIMARY KEY, grp0 INT, grp1 INT, val0 INT, val1 INT) WITH replicas=2,partitions=10");
         sql("CREATE TABLE test_one_col_idx (pk INT PRIMARY KEY, col0 INT)");
 
-        // TODO: https://issues.apache.org/jira/browse/IGNITE-17304 uncomment this
-        // sql("CREATE INDEX test_idx ON test(grp0, grp1)");
-        // sql("CREATE INDEX test_one_col_idx_idx ON test_one_col_idx(col0)");
+         sql("CREATE INDEX test_idx ON test(grp0, grp1)");
+         sql("CREATE INDEX test_one_col_idx_idx ON test_one_col_idx(col0)");
 
         for (int i = 0; i < ROWS; i++) {
             sql("INSERT INTO test (id, grp0, grp1, val0, val1) VALUES (?, ?, ?, ?, ?)", i, i / 10, i / 100, 1, 2);


[ignite-3] 02/03: Unmute tests. ignite-16905

Posted by am...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

amashenkov pushed a commit to branch ignite-18625
in repository https://gitbox.apache.org/repos/asf/ignite-3.git

commit c10aa26423e518a120873652e345ba913157cb1d
Author: amashenkov <an...@gmail.com>
AuthorDate: Thu Jan 26 16:51:08 2023 +0300

    Unmute tests. ignite-16905
---
 .../ignite/jdbc/ItJdbcResultSetSelfTest.java       | 29 ++++++++--------------
 1 file changed, 10 insertions(+), 19 deletions(-)

diff --git a/modules/jdbc/src/integrationTest/java/org/apache/ignite/jdbc/ItJdbcResultSetSelfTest.java b/modules/jdbc/src/integrationTest/java/org/apache/ignite/jdbc/ItJdbcResultSetSelfTest.java
index ab8721be4f..ab959c95cc 100644
--- a/modules/jdbc/src/integrationTest/java/org/apache/ignite/jdbc/ItJdbcResultSetSelfTest.java
+++ b/modules/jdbc/src/integrationTest/java/org/apache/ignite/jdbc/ItJdbcResultSetSelfTest.java
@@ -52,7 +52,7 @@ public class ItJdbcResultSetSelfTest extends AbstractJdbcSelfTest {
     private static final String STATIC_SQL =
             "SELECT 1::INTEGER as id, true as boolVal, 1::TINYINT as byteVal, 1::SMALLINT as shortVal, 1::INTEGER as intVal, 1::BIGINT "
                     + "as longVal, 1.0::FLOAT as floatVal, 1.0::DOUBLE as doubleVal, 1.0::DECIMAL as bigVal, "
-                    + "'1' as strVal, '1', '1901-02-01'::DATE as dateVal, '01:01:01'::TIME as timeVal, 1::TIMESTAMP as tsVal;";
+                    + "'1' as strVal, '1', '1901-02-01'::DATE as dateVal, '01:01:01'::TIME as timeVal, 0::TIMESTAMP as tsVal;";
 
     /** SQL query. */
     private static final String SQL_SINGLE_RES = "select id, boolVal, byteVal, shortVal, intVal, longVal, floatVal, "
@@ -486,7 +486,6 @@ public class ItJdbcResultSetSelfTest extends AbstractJdbcSelfTest {
     }
 
     @Test
-    @Disabled("https://issues.apache.org/jira/browse/IGNITE-16905")
     public void testDate() throws Exception {
         ResultSet rs = stmt.executeQuery(STATIC_SQL);
 
@@ -520,7 +519,6 @@ public class ItJdbcResultSetSelfTest extends AbstractJdbcSelfTest {
      */
     @SuppressWarnings("deprecation")
     @Test
-    @Disabled("https://issues.apache.org/jira/browse/IGNITE-16905")
     public void testTime() throws Exception {
         ResultSet rs = stmt.executeQuery(STATIC_SQL);
 
@@ -546,28 +544,21 @@ public class ItJdbcResultSetSelfTest extends AbstractJdbcSelfTest {
     }
 
     @Test
-    @Disabled("https://issues.apache.org/jira/browse/IGNITE-16905")
     public void testTimestamp() throws Exception {
         ResultSet rs = stmt.executeQuery(STATIC_SQL);
 
-        int cnt = 0;
+        assertTrue(rs.next());
 
-        while (rs.next()) {
-            if (cnt == 0) {
-                assertEquals(-10800000, rs.getTimestamp("tsVal").getTime());
-                assertEquals(new Date(new Timestamp(-10800000).getTime()), rs.getDate(14));
-                assertEquals(new Time(new Timestamp(-10800000).getTime()), rs.getTime(14));
-                assertEquals(new Timestamp(-10800000), rs.getTimestamp(14));
-
-                assertEquals(new Date(new Timestamp(-10800000).getTime()), rs.getObject(14, Date.class));
-                assertEquals(new Time(new Timestamp(-10800000).getTime()), rs.getObject(14, Time.class));
-                assertEquals(new Timestamp(-10800000), rs.getObject(14, Timestamp.class));
-            }
+        assertEquals(-10800000, rs.getTimestamp("tsVal").getTime());
+        assertEquals(new Date(new Timestamp(-10800000).getTime()), rs.getDate(14));
+        assertEquals(new Time(new Timestamp(-10800000).getTime()), rs.getTime(14));
+        assertEquals(new Timestamp(-10800000), rs.getTimestamp(14));
 
-            cnt++;
-        }
+        assertEquals(new Date(new Timestamp(-10800000).getTime()), rs.getObject(14, Date.class));
+        assertEquals(new Time(new Timestamp(-10800000).getTime()), rs.getObject(14, Time.class));
+        assertEquals(new Timestamp(-10800000), rs.getObject(14, Timestamp.class));
 
-        assertEquals(1, cnt);
+        assertFalse(rs.next());
     }
 
     @Test
diff --git a/modules/runner/src/integrationTest/java/org/apache/ignite/internal/sql/engine/ItOrToUnionRuleTest.java b/modules/runner/src/integrationTest/java/org/apache/ignite/internal/sql/engine/ItOrToUnionRuleTest.java
index ada71a653a..9ac7ee61fb 100644
--- a/modules/runner/src/integrationTest/java/org/apache/ignite/internal/sql/engine/ItOrToUnionRuleTest.java
+++ b/modules/runner/src/integrationTest/java/org/apache/ignite/internal/sql/engine/ItOrToUnionRuleTest.java
@@ -20,12 +20,12 @@ package org.apache.ignite.internal.sql.engine;
 import static org.apache.ignite.internal.sql.engine.util.QueryChecker.containsIndexScan;
 import static org.apache.ignite.internal.sql.engine.util.QueryChecker.containsTableScan;
 import static org.apache.ignite.internal.sql.engine.util.QueryChecker.containsUnion;
+import static org.hamcrest.CoreMatchers.containsString;
 import static org.hamcrest.CoreMatchers.not;
 
 import java.util.List;
 import org.hamcrest.CoreMatchers;
 import org.junit.jupiter.api.BeforeAll;
-import org.junit.jupiter.api.Disabled;
 import org.junit.jupiter.api.Test;
 
 /**
@@ -38,7 +38,6 @@ import org.junit.jupiter.api.Test;
  * <p>SELECT * FROM products WHERE category = 'Photo' UNION ALL SELECT * FROM products WHERE subcategory ='Camera Media' AND LNNVL(category,
  * 'Photo');
  */
-@Disabled("https://issues.apache.org/jira/browse/IGNITE-17304")
 public class ItOrToUnionRuleTest extends AbstractBasicIntegrationTest {
     public static final String IDX_SUBCAT_ID = "IDX_SUBCAT_ID";
 
@@ -111,7 +110,7 @@ public class ItOrToUnionRuleTest extends AbstractBasicIntegrationTest {
     }
 
     /**
      * Check 'OR -> UNION' rule is applied for equality conditions on indexed columns.
      *
      * @throws Exception If failed.
      */
@@ -120,10 +119,11 @@ public class ItOrToUnionRuleTest extends AbstractBasicIntegrationTest {
         assertQuery("SELECT * "
                 + "FROM products "
                 + "WHERE subcategory = 'Camera Lens' "
+                + "OR subcategory = 'Camera Tripod'"
                 + "OR subcategory = 'Other'")
-                .matches(containsUnion(true))
-                .matches(containsIndexScan("PUBLIC", "PRODUCTS", "IDX_SUBCATEGORY"))
+                .matches(not(containsUnion(true)))
                 .matches(containsIndexScan("PUBLIC", "PRODUCTS", "IDX_SUBCATEGORY"))
+                .matches(containsString("searchBounds=[[MultiBounds"))
                 .returns(3, "Photo", 1, "Camera Lens", 12, "Lens 1")
                 .returns(4, "Photo", 1, "Other", 12, "Charger 1")
                 .returns(6, "Video", 2, "Camera Lens", 22, "Lens 3")
@@ -195,8 +195,8 @@ public class ItOrToUnionRuleTest extends AbstractBasicIntegrationTest {
                 + "FROM products "
                 + "WHERE name = 'Canon' "
                 + "OR category = 'Video'")
-                .matches(containsUnion(true))
-                .matches(containsIndexScan("PUBLIC", "PRODUCTS", "IDX_CATEGORY"))
+                .matches(not(containsUnion(true)))
+                .matches(containsTableScan("PUBLIC", "PRODUCTS"))
                 .returns(5, "Video", 2, "Camera Media", 21, "Media 3")
                 .returns(6, "Video", 2, "Camera Lens", 22, "Lens 3")
                 .returns(7, "Video", 1, null, 0, "Canon")
@@ -111,7 +110,7 @@ public class ItOrToUnionRuleTest extends AbstractBasicIntegrationTest {
 
     /**
-     * Check 'OR -> UNION' rule is applied for equality conditions on indexed columns.
+     * Check 'OR -> UNION' rule is not applied for equality conditions on indexed columns. Multibounds condition is used instead.
      *
      * @throws Exception If failed.